enum PlaceSnippet {
Before(SyntaxElement),
After(SyntaxElement),
Over(SyntaxElement),
OverGroup(Vec<SyntaxElement>),
}Variants
Before(SyntaxElement)
Place a tabstop before an element
After(SyntaxElement)
Place a tabstop before an element
Over(SyntaxElement)
Place a placeholder snippet in place of the element
OverGroup(Vec<SyntaxElement>)
Place a group of placeholder snippets which are linked together in place of the elements
Implementations
Sourceimpl PlaceSnippet
impl PlaceSnippet
fn finalize_position(self) -> Vec<Snippet>